# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.2.1~36f77cc',
    built_at='2024-01-08 13:03:12Z',
    sha='36f77cc7870b4a1f631d2efc5d32a453d8a1b2ee',
    branch='HEAD',
    tag='v4.2.1',
)
